@@ -1,13 +1,13 @@
-from django_helpers import add_app_url
-import urls
-import time
+# coding=utf-8
+
+from json import dumps
+from hashlib import md5
 
 from django.db.models import Q
 from django.conf.urls import url
 from django.http import HttpResponse
-from django.utils.simplejson import dumps
 
-from django_helpers.templatetags.static_manger import add_jquery, add_jquery_ui
+from django_helpers.templatetags.static_manger import require_jquery, require_jquery_ui
 
 
 lookups = dict()
@@ -17,12 +17,29 @@ class AutoComplete(object):
     search_fields = []
     url_search_parameters = None
     requires_auth = False
+    id_name = 'id'
+    label_name = 'label'
 
-    __name__ = "__undefined__"
+    def __init__(self):
+        register(type(self))
 
-    def search_term(self, term):
+    def get_queryset(self, request):
+        """
+        This function can be overridden to return custom query set.
+        @return: The query set for performing extra searches.
+        """
+        return self.query_set
+
+    def search_term(self, queryset, term):
+        """
+        Performs a simple database search for the term given.
+        This function will performs a __contains in the given
+        fields of the query set.
+
+        @param term: str A search term
+        @return: django.db.models.query.QuerySet a result query set.
+        """
         query = None
-        queryset = self.query_set
         fields = self.search_fields
         for field in fields:
             kwargs = {field + "__contains": term}
@@ -33,6 +50,12 @@ class AutoComplete(object):
         return queryset.filter(query)
 
     def search_url_paramters(self, query, url_params):
+        """
+        This function performs a query lookup with the parameters from the url.
+        @param query:
+        @param url_params:
+        @return:
+        """
         url_search_parameters = self.url_search_parameters
         if url_search_parameters is not None:
             for parameter in url_search_parameters:
@@ -40,15 +63,27 @@ class AutoComplete(object):
                 query = query.filter(**args_dict)
         return query
 
-    def search(self, term, url_params):
-        query = self.search_term(term)
+    def search(self, queryset, term, url_params):
+        query = self.search_term(queryset, term)
         return self.search_url_paramters(query, url_params)
 
     def get_instances(self, ids):
+        """
+        Returns a queryset with the instances with given list of ids.
+        This function is mainly used in many to many fields.
+
+        @param ids: A list/enumerable of primary keys for which the datas has to be returned.
+        @return: django.db.models.query.QuerySet
+        """
         return self.query_set.filter(pk__in=ids)
 
-    def get_instance(self, id):
-        return self.query_set.get(pk=id)
+    def get_instance(self, pk):
+        """
+
+        @param pk: The primary key for which the instance has to be returned.
+        @return: A single instance of the current Model.
+        """
+        return self.query_set.get(pk=pk)
 
     def simple_format(self, instance, string, *fields):
         lst = []
@@ -57,9 +92,19 @@ class AutoComplete(object):
         return string % tuple(lst)
 
     def format_value(self, instance):
-        return str(instance)
+        """
+        Returns the formatted values that represents the current instance.
+        @param instance:
+        @return:
+        """
+        return unicode(instance)
 
     def get_search_term(self, request):
+        """
+        @author Muhammed K K
+        @param request: django.http.HttpRequest current django request
+        @return: str The term to be searched.
+        """
         term = request.GET.get("term")
         if term is None:
             term = request.GET.get("q")
@@ -67,21 +112,26 @@ class AutoComplete(object):
 
     def get_results(self, request, params):
         term = self.get_search_term(request)
-        query = self.search(term, params)
+        query = self.get_queryset(request)
+        query = self.search(query, term, params)
         results = []
         for result in query:
             val = self.format_value(result)
-            # Renamed value for adding support for
-            # jQuery token field. The value can be
-            # controlled for jQuery auto complete.
             results.append({
-                "id": result.id,
-                "label": val,
+                self.id_name: result.id,
+                self.label_name: val,
             })
         return results
 
 
 def autocomplete_lookup(request, lookup, **kwargs):
+    """
+
+    @param request: django.http.HttpRequest
+    @param lookup: name of the lookup
+    @param kwargs: extra url parameters
+    @return: django.http.HttpResponse
+    """
     # If lookup does not exists then return blank array.
     # This is prevent any exceptions at runtime.
     if not lookups.has_key(lookup):
@@ -96,27 +146,30 @@ def autocomplete_lookup(request, lookup, **kwargs):
 def create_reg(name):
     return "(?P<%s>.*)/" % name
 
+
 url_prefix = 'auto-complete-'
 
-def register(autocomplete_class):
-    add_app_url('auto-complete', urls)
 
-    add_jquery()
-    add_jquery_ui()
+def register(autocomplete_class):
+    require_jquery()
+    require_jquery_ui()
 
     if isinstance(autocomplete_class, AutoComplete):
         raise Exception("AutoComplete class is required not instance.")
 
     if not hasattr(autocomplete_class, 'name'):
-        name = str(time.time())
-        name = name.replace('.', '')
+        name = md5(unicode(autocomplete_class)).hexdigest()
     else:
         name = getattr(autocomplete_class, 'name')
 
     if not name.startswith(url_prefix):
         name = url_prefix + name
+
     setattr(autocomplete_class, 'name', name)
 
+    if name in lookups:
+        return
+
     lookups[name] = autocomplete_class
     reg = "%s/" % name
     extra_url_parameters = autocomplete_class.url_search_parameters
@@ -129,3 +182,10 @@ def register(autocomplete_class):
         "lookup": name
     })
     urls.urlpatterns.append(pattern)
+    return autocomplete_class
+
+# Import last to disable recursive imports
+
+from django_helpers import add_app_url
+import urls
+add_app_url('auto-complete', urls)
\ No newline at end of file
