@@ -1,5 +1,6 @@
+# coding=utf-8
 from django_helpers.helpers.views import render_to_string
-from django_helpers.templatetags.static_manger import add_js_file, add_css_file, add_jquery
+from django_helpers.templatetags.static_manger import add_js_file, add_css_file, require_jquery
 
 __author__ = 'ajumell'
 
@@ -89,7 +90,7 @@ class NivoSlider(object):
     css_class = ""
 
     def __init__(self):
-        add_jquery()
+        require_jquery()
         # Prevent duplicate slides in each request
         self.images = self.images[:]
         add_js_file('nivo-slider/js/jquery.nivo.slider.pack.js')
