@@ -1,7 +1,11 @@
+# coding=utf-8
 __author__ = 'ajumell'
 
 from django.conf import settings
-import tweepy
+try:
+    import tweepy
+except:
+    tweepy = None
 
 HasAuth = False
 
