@@ -1,3 +1,4 @@
+# coding=utf-8
 from django import template
 from django.conf import settings
 from django.template.base import TemplateSyntaxError
@@ -20,7 +21,7 @@ class GetAttrNode(Node):
         tkn = p.compile_filter(n)
         n = tkn.resolve(context)
         if n:
-            v = str(v) + '.' + str(n)
+            v = unicode(v) + '.' + unicode(n)
         v = p.compile_filter(v)
         return v.resolve(context)
 
@@ -37,7 +38,7 @@ class GetMatrixNode(Node):
         p = self.parser
         tkn = p.compile_filter(val)
         k = tkn.resolve(context)
-        if s: return str(k)
+        if s: return unicode(k)
         return k
 
     def render(self, context):
