@@ -1,15 +1,16 @@
+# coding=utf-8
 from django_helpers.helpers.templatetags import TemplateNode, parse_args
 from django_helpers.helpers.views import render_to_string
-from django_helpers.templatetags.static_manger import register, add_jquery
+from django_helpers.templatetags.static_manger import register, require_jquery
 
 
 __author__ = 'ajumell'
 
-class BackToTopNode(TemplateNode):
 
+class BackToTopNode(TemplateNode):
     def __init__(self, args, kwargs):
         TemplateNode.__init__(self, args, kwargs)
-        add_jquery()
+        require_jquery()
 
     def render(self, context):
         args = self.args
@@ -25,10 +26,11 @@ class BackToTopNode(TemplateNode):
         else:
             p = 100
 
-        return render_to_string(template,{
+        return render_to_string(template, {
             'position': p
         })
 
+
 @register.tag
 def back_to_top(parser, token):
     bits = token.split_contents()
